@@ -1,4 +1,4 @@
-#![allow(dead_code)]
+#![allow(dead_code, cenum_impl_drop_cast)]
 
 // check dtor calling order when casting enums.
 
